==> vmaid-2.1.7.tar.gz: vmaid-2.1.7/w32loader/w32dlg.h <==
/*
    w32loader
    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __W32DLG_H__
#define __W32DLG_H__


/* ja:ダイアログ */
#define DS_ABSALIGN      0x0001
#define DS_SYSMODAL      0x0002
#define DS_3DLOOK        0x0004
#define DS_FIXEDSYS      0x0008
#define DS_NOFAILCREATE  0x0010
#define DS_LOCALEDIT     0x0020
#define DS_SETFONT       0x0040
#define DS_MODALFRAME    0x0080
#define DS_NOIDLEMSG     0x0100
#define DS_SETFOREGROUND 0x0200
#define DS_CONTROL       0x0400
#define DS_CENTER        0x0800
#define DS_CENTERMOUSE   0x1000
#define DS_CONTEXTHELP   0x2000
#define DS_USEPIXELS     0x8000
#define DS_SHELLFONT     (DS_SETFONT|DS_FIXEDSYS)
#define DM_GETDEFID   (WM_USER+0)
#define DM_SETDEFID   (WM_USER+1)
#define DM_REPOSITION (WM_USER+2)
#define DC_HASDEFID 0x534b


#endif /* not __W32DLG_H__ */

==> vmaid-2.2.3.tar.gz: vmaid-2.2.3/w32loader/w32dlg.h <==
/*
    w32loader
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __W32DLG_H__
#define __W32DLG_H__


G_BEGIN_DECLS


/* ja:ダイアログ */
#define DS_ABSALIGN      0x0001
#define DS_SYSMODAL      0x0002
#define DS_3DLOOK        0x0004
#define DS_FIXEDSYS      0x0008
#define DS_NOFAILCREATE  0x0010
#define DS_LOCALEDIT     0x0020
#define DS_SETFONT       0x0040
#define DS_MODALFRAME    0x0080
#define DS_NOIDLEMSG     0x0100
#define DS_SETFOREGROUND 0x0200
#define DS_CONTROL       0x0400
#define DS_CENTER        0x0800
#define DS_CENTERMOUSE   0x1000
#define DS_CONTEXTHELP   0x2000
#define DS_USEPIXELS     0x8000
#define DS_SHELLFONT     (DS_SETFONT|DS_FIXEDSYS)
#define DM_GETDEFID   (WM_USER+0)
#define DM_SETDEFID   (WM_USER+1)
#define DM_REPOSITION (WM_USER+2)
#define DC_HASDEFID 0x534b


G_END_DECLS


#endif /* not __W32DLG_H__ */
